==> igloo_0_1_8.tar.tgz: igloo_0_1_8/igloo/get_file.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of Igloo
//
// Copyright (C) 2003, 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------


include "config/config_igloo.inc.php";


if (isset($_REQUEST[session_name()])) {
	session_start();
	$_SESSION['session_last_auto_update_datetime'] = time();
	//writeLogFile($_REQUEST[session_name()]);
}

$path = $c_node['dir']['asset_path'] . $_REQUEST['file'];

if (is_file($path)) {
	$extension = substr($path, -3);
	
	global $c_node;
	
	$mime = "image/png";
	
	foreach($c_node['file']['mime'] as $key => $i):
		if ($extension == $i['suffix']) {
			$mime = $c_node['file']['mime'][$key]['mime'];
			break;
		}
	endforeach;
	
	header("Content-type: " . $mime);
	
    @readfile($path);
}
else {
	$path = $c_node['dir']['asset_path'] . $c_node['file']['image']['broken_image'];
	header("Content-type: image/png");
	@readfile($path);
}

?>

==> igloo_0_1_9.tar.tgz: igloo_0_1_9/igloo/get_file.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of Igloo
//
// Copyright (C) 2003, 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------


include "config/config_igloo.inc.php";


if (!empty($_REQUEST['reloadsession'])) {
	session_name($c_node['node']['php_session_name']);
	session_start();
	
	//include "inc/functions.inc.php";
	//$log = "session_keep_alive " . session_name() . " " . session_id() . " at " . time();
	//writeLogFile($log);
	
	setcookie(session_name(),session_id(),time()+ini_get('session.gc_maxlifetime'));
	
	// patch for Apache 2+ PHP mod private cache control bug - TC
	if (!empty($_SERVER['SERVER_SOFTWARE']) && strstr($_SERVER['SERVER_SOFTWARE'], 'Apache/2')) {
		header ('Cache-Control: no-cache, pre-check=0, post-check=0');
	}
	else {
		header ('Cache-Control: private, pre-check=0, post-check=0, max-age=0');
	}
	
	header ('Expires: 0');
	header ('Pragma: no-cache');
}

$path = $c_node['dir']['asset_path'] . $_REQUEST['file'];

if (is_file($path)) {
	$extension = substr($path, -3);
	
	global $c_node;
	
	$mime = "image/png";
	
	foreach($c_node['file']['mime'] as $key => $i):
		if ($extension == $i['suffix']) {
			$mime = $c_node['file']['mime'][$key]['mime'];
			break;
		}
	endforeach;
	
	header("Content-type: " . $mime);
	
    @readfile($path);
}
else {
	$path = $c_node['dir']['asset_path'] . $c_node['file']['image']['broken_image'];
	header("Content-type: image/png");
	@readfile($path);
}

?>
